@@ -6,13 +6,13 @@ from terralab.logic import auth_logic
 
 
 @click.command()
-def logout():
+def logout() -> None:
     """Remove access credentials"""
     auth_logic.clear_local_token()
 
 
 @click.command(hidden=True)
 @click.argument("token", required=True)
-def login_with_oauth(token):
+def login_with_oauth(token: str) -> None:
     """Login using oauth bearer token from gcloud"""
     auth_logic.login_with_oauth(token)
